@@ -1,5 +1,5 @@
 /*
- * Copyright 1999-2006 University of Chicago
+ * Copyright 1999-2014 University of Chicago
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,13 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 #ifndef GLOBUS_SCHEDULER_EVENT_GENERATOR_STDOUT_H
 #define GLOBUS_SCHEDULER_EVENT_GENERATOR_STDOUT_H
 
 #include "globus_common.h"
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+extern "C" {
 #endif
 
 extern globus_module_descriptor_t
@@ -34,8 +35,8 @@ globus_scheduler_event_generator_stdout_handler(
     void *                              arg,
     const globus_scheduler_event_t *    event);
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-EXTERN_C_END
+#ifdef __cplusplus
+}
 #endif
 
 #endif /* GLOBUS_SCHEDULER_EVENT_GENERATOR_H */
